@@ -11,6 +11,7 @@
 #include "agt.h"
 #include "agt_cb.h"
 #include "agt_cli.h"
+#include "agt_commit_complete.h"
 #include "agt_timer.h"
 #include "agt_util.h"
 #include "agt_not.h"
@@ -109,23 +110,19 @@ void oper_status_update(val_value_t* cur_val)
         val_init_from_template(last_change_val, last_change_obj);
         val_set_simval_obj(last_change_val, last_change_obj, tstamp_buf);
 
-        val = val123_find_match(root_prev_val, cur_val);
-        val_remove_child(val);
-        val_free_value(val);
-        res=val123_clone_instance(root_prev_val, cur_val, &val);
-
-        last_change_prev_val = val_find_child(val->parent, "ietf-interfaces", "last-change");
+        last_change_prev_val = val_find_child(prev_val->parent, "ietf-interfaces", "last-change");
         if(last_change_prev_val) {
             val_remove_child(last_change_prev_val);
             val_free_value(last_change_prev_val);
         }
-        val_add_child(last_change_val, val->parent);
+        val_add_child(last_change_val, prev_val->parent);
 
         /* notify */
         name_val=val_find_child(cur_val->parent,"ietf-interfaces","name");
         assert(name_val);
         printf("Notification /interfaces/interface[name=%s]: oper-status changes from %s to %s at %s\n", VAL_STRING(name_val), VAL_STRING(prev_val),VAL_STRING(cur_val), VAL_STRING(last_change_val));
         my_send_link_state_notification(VAL_STRING(cur_val), VAL_STRING(name_val));
+        val_set_simval_obj(prev_val, prev_val->obj, VAL_STRING(cur_val));
 
     }
 }
@@ -210,6 +207,46 @@ static status_t
     return res;
 }
 
+static status_t
+    get_speed(ses_cb_t *scb,
+                       getcb_mode_t cbmode,
+                       val_value_t *vir_val,
+                       val_value_t  *dst_val)
+{
+    status_t res;
+    val_value_t *interface_val;
+    val_value_t *name_val;
+    FILE* f;
+    char filename[NCX_MAX_LINELEN];
+    char status_buf[NCX_MAX_LINELEN];
+    char* fgets_ret;
+
+    interface_val = vir_val->parent;
+    assert(interface_val);
+
+    name_val = val_find_child(interface_val,
+                              "ietf-interfaces",
+                              "name");
+    assert(name_val);
+
+    /* open the /proc/net/dev file for reading */
+    sprintf(filename, "/sys/class/net/%s/speed", VAL_STRING(name_val));
+    f = fopen(filename, "r");
+    if (f == NULL) {
+        return ERR_NCX_SKIPPED;
+    }
+    fgets_ret = fgets((char *)status_buf, NCX_MAX_LINELEN, f);
+    fclose(f);
+    if(fgets_ret==NULL) {
+        return ERR_NCX_SKIPPED;
+    }
+    strtok(status_buf,"\n");
+
+    VAL_UINT64(dst_val) = (uint64_t)1000000*atoi(status_buf);
+
+    return NO_ERR;
+}
+
 /*
 
 Inter-|   Receive                                                |  Transmit
@@ -291,6 +328,13 @@ static status_t
     	str++;
     }
 
+    if(NULL!=getenv("INTERFACE_NAME_PREFIX")) {
+        char* prefix=getenv("INTERFACE_NAME_PREFIX");
+        if(strlen(name)<strlen(prefix) || 0!=memcmp(prefix,name,strlen(prefix))) {
+            return NO_ERR; /*skip*/
+        }
+    }
+
     /* interface */
     interface_obj = obj_find_child(interfaces_val->obj,
                                    "ietf-interfaces",
@@ -341,7 +385,7 @@ static status_t
 
     val_add_child(oper_status_val, interface_val);
 
-    /* interface/oper-state */
+    /* interface/last-change */
     last_change_obj = obj_find_child(interface_obj,
                          "ietf-interfaces",
                          "last-change");
@@ -355,6 +399,20 @@ static status_t
 
     val_add_child(last_change_val, interface_val);
 
+    /* interface/speed */
+    obj = obj_find_child(interface_obj,
+                         "ietf-interfaces",
+                         "speed");
+
+    val = val_new_value();
+    assert(val);
+
+    val_init_virtual(val,
+                     get_speed,
+                     obj);
+
+    val_add_child(val, interface_val);
+
     /* interface/statistics */
     statistics_obj = obj_find_child(interface_obj,
                          "ietf-interfaces",
@@ -485,6 +543,138 @@ static status_t init2_w_nmda(void)
 {
 }
 
+static void interface_delete(val_value_t* interface_val)
+{
+    int ret;
+    int n;
+    char* cmd_buf;
+    val_value_t* name_val;
+
+    name_val = val_find_child(interface_val,"ietf-interfaces","name");
+    assert(name_val);
+
+    n = snprintf(NULL, 0, "ifconfig %s down", VAL_STRING(name_val));
+    assert(n>0);
+    cmd_buf=malloc(n+1);
+    snprintf(cmd_buf, n+1, "ifconfig %s down", VAL_STRING(name_val));
+    log_info("Interface down: %s\n", cmd_buf);
+    ret=system(cmd_buf);
+    //assert(ret==0);
+    if(ret!=0) {
+        perror(cmd_buf);
+    }
+    free(cmd_buf);
+}
+
+static void interface_create(val_value_t* interface_val)
+{
+    int ret;
+    int n;
+    char* cmd_buf;
+    val_value_t* name_val;
+
+    name_val = val_find_child(interface_val,"ietf-interfaces","name");
+    assert(name_val);
+
+    n = snprintf(NULL, 0, "ifconfig %s up", VAL_STRING(name_val));
+    assert(n>0);
+    cmd_buf=malloc(n+1);
+    snprintf(cmd_buf, n+1, "ifconfig %s up", VAL_STRING(name_val));
+    log_info("Interface up: %s\n", cmd_buf);
+    ret=system(cmd_buf);
+    //assert(ret==0);
+    if(ret!=0) {
+        perror(cmd_buf);
+    }
+
+    free(cmd_buf);
+}
+ 
+static int update_config(val_value_t* config_cur_val, val_value_t* config_new_val)
+{
+
+    status_t res;
+
+    val_value_t *interfaces_cur_val, *interface_cur_val;
+    val_value_t *interfaces_new_val, *interface_new_val;
+
+
+    if(config_new_val == NULL) {
+        interfaces_new_val = NULL;
+    } else {
+        interfaces_new_val = val_find_child(config_new_val,
+                               "ietf-interfaces",
+                               "interfaces");
+    }
+
+    if(config_cur_val == NULL) {
+        interfaces_cur_val = NULL;
+    } else {
+        interfaces_cur_val = val_find_child(config_cur_val,
+                                       "ietf-interfaces",
+                                       "interfaces");
+    }
+
+    /* 2 step (delete/add) interface configuration */
+
+    /* 1. deactivation loop - deletes all deleted interface -s */
+    if(interfaces_cur_val!=NULL) {
+        for (interface_cur_val = val_get_first_child(interfaces_cur_val);
+             interface_cur_val != NULL;
+             interface_cur_val = val_get_next_child(interface_cur_val)) {
+            interface_new_val = val123_find_match(config_new_val, interface_cur_val);
+            if(interface_new_val==NULL) {
+                interface_delete(interface_cur_val);
+            }
+        }
+    }
+
+    /* 2. activation loop - creates all new interface -s */
+    if(interfaces_new_val!=NULL) {
+        for (interface_new_val = val_get_first_child(interfaces_new_val);
+             interface_new_val != NULL;
+             interface_new_val = val_get_next_child(interface_new_val)) {
+            interface_cur_val = val123_find_match(config_cur_val, interface_new_val);
+            if(interface_cur_val==NULL) {
+                interface_create(interface_new_val);
+            }
+        }
+    }
+    return NO_ERR;
+}
+
+static val_value_t* prev_root_val = NULL;
+static int update_config_wrapper()
+{
+    cfg_template_t        *runningcfg;
+    status_t res;
+    runningcfg = cfg_get_config_id(NCX_CFGID_RUNNING);
+    assert(runningcfg!=NULL && runningcfg->root!=NULL);
+    if(prev_root_val!=NULL) {
+        val_value_t* cur_root_val;
+        cur_root_val = val_clone_config_data(runningcfg->root, &res);
+        if(0==val_compare(cur_root_val,prev_root_val)) {
+            /*no change*/
+            val_free_value(cur_root_val);
+            return 0;
+        }
+        val_free_value(cur_root_val);
+    }
+    update_config(prev_root_val, runningcfg->root);
+
+    if(prev_root_val!=NULL) {
+        val_free_value(prev_root_val);
+    }
+    prev_root_val = val_clone_config_data(runningcfg->root, &res);
+    return 0;
+}
+
+static status_t y_commit_complete(void)
+{
+    update_config_wrapper();
+    return NO_ERR;
+}
+
 /* The 3 mandatory callback functions: y_ietf_interfaces_init, y_ietf_interfaces_init2, y_ietf_interfaces_cleanup */
 
 status_t
@@ -531,6 +721,10 @@ status_t
         &mod);
     assert(res == NO_ERR);
 
+    res=agt_commit_complete_register("ietf-interfaces" /*SIL id string*/,
+                                     y_commit_complete);
+    assert(res == NO_ERR);
+
     return res;
 }
 
@@ -596,6 +790,9 @@ status_t y_ietf_interfaces_init2(void)
                            my_timer_fn,
                            interfaces_val/*cookie*/,
                            &timer_id);
+
+    y_commit_complete();
+
     return res;
 }
 
