@@ -46,7 +46,6 @@ date         init     comment
 #include "agt_cli.h"
 #include "agt_connect.h"
 #include "agt_hello.h"
-#include "agt_if.h"
 #include "agt_ncx.h"
 #include "agt_nmda.h"
 #include "agt_not.h"
@@ -614,6 +613,7 @@ status_t
     status_t            res;
     uint32              modlen;
     boolean             startup_loaded;
+    ncx_save_deviations_t *savedev;
 
     log_debug3("\nServer Init-2 Starting...");
 
@@ -742,13 +742,7 @@ status_t
     if (res != NO_ERR) {
         return res;
     }
-#if 0
-    /* load the NETCONF interface monitoring data model module */
-    res = agt_if_init();
-    if (res != NO_ERR) {
-        return res;
-    }
-#endif
+
     /* initialize the NCX server core callback functions.
      * the schema (yuma-netconf.yang) for these callbacks was 
      * already loaded in the common ncx_init
@@ -857,6 +851,49 @@ status_t
         return ERR_NCX_OPERATION_FAILED;
     }
 
+    /* Finish filling in the deviation modules' import structures.
+     * Loading deviation modules skips over this step, but since all
+     * modules should be loaded by this point, iterate through the
+     * imports and search for each missing module.
+     */
+
+    for (savedev = (ncx_save_deviations_t *)dlq_firstEntry(&agt_profile.agt_savedevQ);
+         savedev && res == NO_ERR;
+         savedev = (ncx_save_deviations_t *)dlq_nextEntry(savedev)) {
+        res = ncxmod_process_deviation_imports(savedev);
+    }
+
+    if (res != NO_ERR) {
+        log_error("\nError: one or more modules imported by %s could not be found.",
+                  savedev->devmodule);
+        return ERR_NCX_OPERATION_FAILED;
+    }
+
+    /* After the deviations have been resolved, any nodes to be deleted
+     * will have been marked as such.  ncxmod_apply_deviations() will
+     * cause those nodes to actually be deleted.  This happens in a
+     * separate loop because, in the case that the target node is the
+     * result of a yang augment statement, the module in which the target
+     * obj_template_t will be found may (generally will) be different
+     * than the module in which the deviation was resolved.
+     */
+
+    for (retmod = ncx_get_first_module();
+         retmod;
+         retmod = ncx_get_next_module(retmod)) {
+        res = ncxmod_resolve_deviations(retmod, &agt_profile.agt_savedevQ);
+        if (res != NO_ERR)
+            return ERR_NCX_OPERATION_FAILED;
+    }
+
+    for (retmod = ncx_get_first_module();
+         retmod;
+         retmod = ncx_get_next_module(retmod)) {
+        res = ncxmod_apply_deviations(retmod);
+        if (res != NO_ERR)
+            return ERR_NCX_OPERATION_FAILED;
+    }
+
     if (ncx_any_mod_errors()) {
         log_error("\nError: one or more pre-loaded YANG modules"
                   " has fatal errors\n");
@@ -962,13 +999,7 @@ status_t
     if (res != NO_ERR) {
         return res;
     }
-#if 0
-    /* load the interface monitoring callback functions and data */
-    res = agt_if_init2();
-    if (res != NO_ERR) {
-        return res;
-    }
-#endif
+
     /* TBD: load the time filter callbacks
      * this currently does not do anything
      */
@@ -1173,15 +1204,14 @@ void
         agt_acm_cleanup();
         agt_ncx_cleanup();
         agt_hello_cleanup();
-        agt_cli_cleanup();
         agt_nmda_cleanup();
+        agt_cli_cleanup();
         agt_yang_library_cleanup();
         agt_sys_cleanup();
         agt_state_cleanup();
         agt_not_cleanup();
         agt_proc_cleanup();
         y_ietf_netconf_partial_lock_cleanup();
-        agt_if_cleanup();
         y_yuma_time_filter_cleanup();
         agt_ses_cleanup();
         agt_cap_cleanup();
