@@ -53,12 +53,14 @@ date         init     comment
 #include "getcb.h"
 #include "log.h"
 #include "ncxmod.h"
+#include "ncx.h"
 #include "rpc.h"
 #include "ses.h"
 #include "ses_msg.h"
 #include "status.h"
 #include "tstamp.h"
 #include "val.h"
+#include "val123.h"
 #include "xmlns.h"
 #include "xml_util.h"
 #include "uptime.h"
@@ -75,6 +77,8 @@ date         init     comment
 
 #define AGT_SES_SET_MY_SESSION   (const xmlChar *)"set-my-session"
 
+#define AGT_SES_CACHE_MODULE (const xmlChar *)"yuma123-mysession-cache"
+
 /* number of seconds to wait between session timeout checks */
 #define AGT_SES_TIMEOUT_INTERVAL  1
 
@@ -99,6 +103,7 @@ static ses_cb_t  **agtses;
 static ses_total_stats_t *agttotals;
 
 static ncx_module_t *mysesmod;
+static ncx_module_t *mysescachemod;
 
 static time_t     last_timeout_check;
 
@@ -158,6 +163,9 @@ static status_t
                            xml_node_t *methnode)
 {
     val_value_t     *indentval, *linesizeval, *withdefval;
+    val_value_t     *cache_timeout_val;
+    obj_template_t  *output_obj;
+    obj_template_t  *cache_timeout_obj;
     xmlChar          numbuff[NCX_MAX_NUMLEN];
 
     (void)methnode;
@@ -189,9 +197,34 @@ static status_t
         return ERR_INTERNAL_MEM;
     }
 
+    cache_timeout_val = val_new_value();
+    output_obj = obj_find_child(
+        msg->rpc_method,
+        AGT_SES_MODULE,
+        NCX_EL_OUTPUT);
+    assert(output_obj);
+
+    cache_timeout_obj = obj_find_child(
+        output_obj,
+        AGT_SES_CACHE_MODULE,
+        "cache-timeout");
+    assert(cache_timeout_obj);
+
+    cache_timeout_val = val_new_value();
+    if (cache_timeout_val == NULL) {
+        val_free_value(indentval);
+        val_free_value(linesizeval);
+        val_free_value(withdefval);
+        return ERR_INTERNAL_MEM;
+    }
+
+    val_init_from_template(cache_timeout_val, cache_timeout_obj);
+    VAL_UINT(cache_timeout_val) = scb->cache_timeout;
+
     dlq_enque(indentval, &msg->rpc_dataQ);
     dlq_enque(linesizeval, &msg->rpc_dataQ);
     dlq_enque(withdefval, &msg->rpc_dataQ);
+    dlq_enque(cache_timeout_val, &msg->rpc_dataQ);
     msg->rpc_data_type = RPC_DATA_YANG;
     return NO_ERR;
 
@@ -213,6 +246,7 @@ static status_t
                            xml_node_t *methnode)
 {
     val_value_t     *indentval, *linesizeval, *withdefval;
+    val_value_t     *cache_timeout_val;
 
     (void)methnode;
 
@@ -241,6 +275,14 @@ static status_t
             ncx_get_withdefaults_enum(VAL_ENUM_NAME(withdefval));
     }
 
+    /* get the cache-timeout parameter */
+    cache_timeout_val = val_find_child(msg->rpc_input,
+                                AGT_SES_CACHE_MODULE,
+                                "cache-timeout");
+    if (cache_timeout_val && cache_timeout_val->res == NO_ERR) {
+        scb->cache_timeout = VAL_UINT(cache_timeout_val);
+    }
+
     return NO_ERR;
 
 } /* set_my_session_invoke */
@@ -289,6 +331,7 @@ status_t
     }
     next_sesid = 1;
     mysesmod = NULL;
+    mysescachemod = NULL;
 
     agttotals = ses_get_total_stats();
     memset(agttotals, 0x0, sizeof(ses_total_stats_t));
@@ -302,7 +345,16 @@ status_t
                              &agt_profile->agt_savedevQ,
                              &mysesmod);
     if (res != NO_ERR) {
-        return res;
+        return SET_ERROR(res);
+    }
+
+    /* load the netconf-state module */
+    res = ncxmod_load_module(AGT_SES_CACHE_MODULE,
+                             NULL,
+                             &agt_profile->agt_savedevQ,
+                             &mysescachemod);
+    if (res != NO_ERR) {
+        return SET_ERROR(res);
     }
 
     /* set up get-my-session RPC operation */
@@ -878,10 +930,15 @@ boolean
 
     /* process the message */
     if (res == NO_ERR) {
+        uint32 vtimeout_copy = ncx_get_vtimeout_value();
+        ncx123_set_vtimeout_value(scb->cache_timeout);
+
         /* process the message
          * the scb pointer may get deleted !!!
          */
         agt_top_dispatch_msg(&scb);
+
+        ncx123_set_vtimeout_value(vtimeout_copy);
     } else {
         if (LOGINFO) {
             log_info("\nReset xmlreader failed for session %d (%s)",
