@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2008 - 2012, Andy Bierman, All Rights Reserved.
+ * Copyright (c) 2013 - 2018, Vladimir Vassilev, All Rights Reserved.
  * 
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -33,8 +34,8 @@ date         init     comment
 #include <string.h>
 #include <math.h>
 
-#include <xmlstring.h>
-#include <xmlreader.h>
+#include <libxml/xmlstring.h>
+#include <libxml/xmlreader.h>
 
 #include "procdefs.h"
 #include "agt.h"
@@ -1706,9 +1707,13 @@ static status_t
  *
  * <foo>fred</foo>
  * <foo>11</foo>
+ * <foo/>
+ * <foo></foo>
  *
  * INPUTS:
  *   see parse_btype_nc parameter list
+ * OUTPUTS:
+ *    *retval will be filled in
  * RETURNS:
  *   status
  *********************************************************************/
@@ -1756,20 +1761,52 @@ static status_t
             res = ERR_NCX_WRONG_NODETYP;
         }
     } else {
-        res = xml_node_match(startnode, 
-                             obj_get_nsid(obj), 
-                             NULL, 
-                             XML_NT_START); 
+        res = xml_node_match(startnode,
+                             obj_get_nsid(obj),
+                             NULL,
+                             XML_NT_START);
+        if (res != NO_ERR) {
+            res = xml_node_match(startnode,
+                                 obj_get_nsid(obj),
+                                 NULL,
+                                 XML_NT_EMPTY);
+            if (res == NO_ERR) {
+                empty = TRUE;
+            }
+        }
     }
 
+    /* get the value string node */
     if (res == NO_ERR && !empty) {
         /* get the next node which should be a string node */
         res = get_xml_node(scb, msg, &valnode, TRUE);
-        if (res != NO_ERR) {
+        if (res == NO_ERR && valnode.nodetyp == XML_NT_END) {
+            res = xml_endnode_match(startnode, &valnode);
+            if(res==NO_ERR) {
+                empty = TRUE;
+                xml_clean_node(&valnode);
+            }
+        } else if (res != NO_ERR) {
             errdone = TRUE;
         }
     }
 
+    if (empty && res==NO_ERR) {
+        /* check the empty string */
+        res = val_union_ok_errinfo(obj_get_typdef(obj),
+                                   EMPTY_STRING,
+                                   retval,
+                                   &errinfo);
+        if(res==NO_ERR) {
+            retval->v.str = xml_strdup(EMPTY_STRING);
+            if (!retval->v.str) {
+                res = ERR_INTERNAL_MEM;
+            }
+        } else {
+            badval = EMPTY_STRING;
+        }
+    }
+
     if (res == NO_ERR && !empty) {
         log_debug3("\nparse_union: expecting string or number node.");
         if (LOGDEBUG4) {
@@ -1778,11 +1815,6 @@ static status_t
 
         /* validate the node type and union node content */
         switch (valnode.nodetyp) {
-        case XML_NT_START:
-            res = ERR_NCX_WRONG_NODETYP_CPX;
-            errnode = &valnode;
-            stopnow = TRUE;
-            break;
         case XML_NT_STRING:
             /* get the non-whitespace string here */
             res = val_union_ok_errinfo(obj_get_typdef(obj), 
@@ -1793,16 +1825,6 @@ static status_t
                 badval = valnode.simval;
             }
             break;
-        case XML_NT_END:
-            stopnow = TRUE;
-            res = val_union_ok_errinfo(obj_get_typdef(obj), 
-                                       EMPTY_STRING, 
-                                       retval, 
-                                       &errinfo);
-            if (res != NO_ERR) {
-                badval = EMPTY_STRING;
-            }
-            break;
         default:
             stopnow = TRUE;
             SET_ERROR(ERR_INTERNAL_VAL);
@@ -2599,8 +2621,8 @@ static status_t
     retval->editop = OP_EDITOP_NONE;
     retval->nsid = startnode->nsid;
 
-    /* check namespace errors except if the type is ANY */
-    nserr = (btyp != NCX_BT_ANY);
+    /* check namespace errors except if the type is ANY* */
+    nserr = (btyp != NCX_BT_ANYDATA && btyp != NCX_BT_ANYXML);
 
     if (retval->obj == NULL) {
         /* in case the parse_metadata_nc function
@@ -2616,7 +2638,8 @@ static status_t
      * to record as many errors as possible
      */
     switch (btyp) {
-    case NCX_BT_ANY:
+    case NCX_BT_ANYDATA:
+    case NCX_BT_ANYXML:
         res = parse_any_nc(scb, msg, startnode, parentdc, retval);
         break;
     case NCX_BT_ENUM:
