@@ -221,6 +221,7 @@ static status_t
                 const char *password,
                 const char *pubkeyfile,
                 const char *privkeyfile,
+                const char *privkeypass,
                 boolean ssh_use_agent)
                 
 {
@@ -393,7 +394,7 @@ agent_done:
                     (mscb->session, user, 
                      (const char *)expand_pubkey, 
                      (const char *)expand_privkey, 
-                     password);
+                     privkeypass ? privkeypass : "");
                 m__free(expand_pubkey);
                 m__free(expand_privkey);
 
@@ -653,7 +654,7 @@ static void
     const char *str;
     char        buffer[1024];
     sprintf(buffer, 
-            "<ncx-connect xmlns=\"http://netconfcentral.org/ns/yuma-ncx\" version=\"1\" user=\"%s\" address=\"localhost\" magic=\"x56o8937ab17eg922z34rwhobskdbyswfehkpsqq3i55a0an960ccw24a4ek864aOpal1t2p\" transport=\"ssh\" port=\"%u\" />\n]]>]]>",
+            "<ncx-connect xmlns=\"http://netconfcentral.org/ns/yuma-ncx\" version=\"1\" user=\"%s\" address=\"127.0.0.1\" magic=\"x56o8937ab17eg922z34rwhobskdbyswfehkpsqq3i55a0an960ccw24a4ek864aOpal1t2p\" transport=\"ssh\" port=\"%u\" />\n]]>]]>",
             user,
             (unsigned int)port);
     ses_putstr(scb, (const xmlChar *)buffer);
@@ -799,9 +800,8 @@ void
 
 }  /* mgr_ses_cleanup */
 
-
 /********************************************************************
-* FUNCTION mgr_ses_new_session
+* FUNCTION mgr_ses_new_session2
 *
 * Create a new session control block and
 * start a NETCONF session with to the specified server
@@ -818,6 +818,7 @@ void
 *   password == user password
 *   pubkeyfile == filespec for client public key
 *   privkeyfile == filespec for client private key
+*   privkeypass == passphrase to unlock private key
 *   target == ASCII IP address or DNS hostname of target
 *   port == NETCONF port number to use, or 0 to use defaults
 *   transport == enum for the transport to use (SSH or TCP)
@@ -837,10 +838,11 @@ void
 *   status
 *********************************************************************/
 status_t
-    mgr_ses_new_session (const xmlChar *user,
+    mgr_ses_new_session2 (const xmlChar *user,
                          const xmlChar *password,
                          const char *pubkeyfile,
                          const char *privkeyfile,
+                         const xmlChar *privkeypass,
                          boolean ssh_use_agent,
                          const xmlChar *target,
                          uint16 port,
@@ -963,7 +965,11 @@ status_t
                          (const char *)password,
                          pubkeyfile,
                          privkeyfile,
+                         (const char *)privkeypass,
                          ssh_use_agent);
+    } else if (res == NO_ERR && transport == SES_TRANSPORT_TCP) {
+        int flags = fcntl(scb->fd, F_GETFL, 0);
+        fcntl(scb->fd, F_SETFL, flags | O_NONBLOCK);
     }
 
     if (res != NO_ERR) {
@@ -1066,6 +1072,71 @@ status_t
 
 }  /* mgr_ses_new_session */
 
+/********************************************************************
+* FUNCTION mgr_ses_new_session
+*
+* Create a new session control block and
+* start a NETCONF session with to the specified server
+*
+* After this functions returns OK, the session state will
+* be in HELLO_WAIT state. An server <hello> must be received
+* before any <rpc> requests can be sent
+*
+* The pubkeyfile and privkeyfile parameters will be used first.
+* If this fails, the password parameter will be checked
+*
+* INPUTS:
+*   user == user name
+*   password == user password
+*   pubkeyfile == filespec for client public key
+*   privkeyfile == filespec for client private key
+*   target == ASCII IP address or DNS hostname of target
+*   port == NETCONF port number to use, or 0 to use defaults
+*   transport == enum for the transport to use (SSH or TCP)
+*   progcb == temp program instance control block,
+*          == NULL if a session temp files control block is not
+*             needed
+*   retsid == address of session ID output
+*   getvar_cb == XPath get varbind callback function
+*   params_val == pointer to val_value_t that may contain
+*         a session-specific --protocols variable to set
+*         == NULL if not used
+*
+* OUTPUTS:
+*   *retsid == session ID, if no error
+*
+* RETURNS:
+*   status
+*********************************************************************/
+status_t
+    mgr_ses_new_session (const xmlChar *user,
+                         const xmlChar *password,
+                         const char *pubkeyfile,
+                         const char *privkeyfile,
+                         boolean ssh_use_agent,
+                         const xmlChar *target,
+                         uint16 port,
+                         ses_transport_t transport,
+                         ncxmod_temp_progcb_t *progcb,
+                         ses_id_t *retsid,
+                         xpath_getvar_fn_t getvar_fn,
+                         val_value_t *params_val)
+{
+    return mgr_ses_new_session2 (user,
+                         password,
+                         pubkeyfile,
+                         privkeyfile,
+                         ""/*privkeypass*/,
+                         ssh_use_agent,
+                         target,
+                         port,
+                         transport,
+                         progcb,
+                         retsid,
+                         getvar_fn,
+                         params_val);
+}
+
 /********************************************************************
 * FUNCTION mgr_ses_free_session
 *
