@@ -2131,6 +2131,18 @@ extern xmlChar *
 extern void
     ncx_set_cur_modQ (dlq_hdr_t *que);
 
+/********************************************************************
+* FUNCTION ncx_get_cur_modQ
+*
+* Get the current module Q
+* This will be used for module searches usually in ncx_modQ
+*
+* INPUTS:
+*    que == Q of ncx_module_t to use
+*********************************************************************/
+dlq_hdr_t *
+    ncx_get_cur_modQ (void);
+
 
 /********************************************************************
 * FUNCTION ncx_reset_modQ
@@ -2944,4 +2956,50 @@ extern boolean
 }  /* end extern 'C' */
 #endif
 
+/********************************************************************
+* FUNCTION identity_get_first_iffeature
+*
+* Get the first if-feature clause (if any) for the specified identity
+*
+* INPUTS:
+*     identity == identity structure to check
+*
+* RETURNS:
+*     pointer to first if-feature struct
+*     NULL if none available
+*********************************************************************/
+const ncx_iffeature_t *
+    identity_get_first_iffeature (const ncx_identity_t *identity);
+
+/********************************************************************
+* FUNCTION identity_get_next_iffeature
+*
+* Get the next if-feature clause (if any)
+*
+* INPUTS:
+*     iffeature == current iffeature struct
+*
+* RETURNS:
+*     pointer to next if-feature struct
+*     NULL if none available
+*********************************************************************/
+const ncx_iffeature_t *
+    identity_get_next_iffeature (const ncx_iffeature_t  *iffeature);
+
+/********************************************************************
+* FUNCTION identity_is_enabled
+*
+* Check any if-feature statement that may
+* cause the specified identity to be invisible
+*
+* INPUTS:
+*    identity == ncx_identity_t to check
+
+* RETURNS:
+*    TRUE if identity is enabled
+*    FALSE if any if-features are present and FALSE
+*********************************************************************/
+extern boolean
+    identity_is_enabled (const ncx_identity_t *identity);
+
 #endif	    /* _H_ncx */
