@@ -639,7 +639,10 @@ typedef struct ncx_module_t_ {
 
     dlq_hdr_t         incchainQ;   /* used if parent == NULL */
 
-    ncx_list_t        devmodlist;     /* for deviations list */
+    /* Q of ncx_save_deviations_t to track modules that deviate this
+     * module.
+     */
+    dlq_hdr_t         devmodlist;
 
    /* yang-library conformance-type {implement,import} */
    boolean implemented;
@@ -673,6 +676,7 @@ typedef struct ncx_identity_t_ {
     xmlChar              *descr;
     xmlChar              *ref;
     ncx_status_t          status;
+    dlq_hdr_t             iffeatureQ;   /* Q of ncx_iffeature_t */
     dlq_hdr_t             appinfoQ;       /* Q of ncx_appinfo_t */
     status_t              res;     /* may be stored with errors */
     boolean               isroot;    /* empty baseQ not an error */
