@@ -941,8 +941,27 @@ extern uint32
     tk_tkptr_quotes (const tk_token_ptr_t  *tkptr);
 
 
+/********************************************************************
+ * FUNCTION set_tkc_error
+ *
+ * utility function for setting and reporting tkc errors.
+ *
+ * INPUTS:
+ *   tkc the parser token chain (may be NULL)
+ *   mod the module
+ *   res the error status.
+ *
+ * RETURNS:
+ *   the error status
+ ***************************************************************/
+extern status_t
+    set_tkc_error( tk_chain_t *tkc,
+                   ncx_module_t *mod,
+                   ncx_error_t *err,
+                   status_t res );
+
 #ifdef __cplusplus
 }  /* end extern 'C' */
 #endif
-                      
+
 #endif	    /* _H_tk */
