@@ -38,7 +38,6 @@ status_t cli123_parse_parm_assignment(obj_template_t* obj, boolean autocomp, con
 status_t cli123_parse_value_string(const char* cli_str, unsigned int* len, char** valstr);
 status_t val123_merge_cplx(val_value_t* dst, val_value_t* src);
 val_value_t* val123_select_obj(val_value_t* parent_val, obj_template_t* child_obj);
-status_t val123_devirtualize(val_value_t* val);
 val_value_t* val123_clone_real(val_value_t* val);
 obj_template_t* obj123_get_top_uses(obj_template_t* obj);
 typ_def_t* typ123_get_first_named_typdef(typ_def_t* typdef);
@@ -68,3 +67,13 @@ ncx_module_t*
     obj123_find_child_mod_from_name(obj_template_t *parent, const char* modname);
 ncx_module_t*
     obj123_find_child_mod_from_prefix(obj_template_t *parent, const char* modprefix);
+void
+    val123_add_virtual_cb (val_value_t *val,
+                      void  *cbfn);
+void
+    tstamp123_datetime_nsec (xmlChar *buff);
+void
+    ncx123_set_vtimeout_value (uint32 sec);
+obj_template_t*
+    val123_get_case_for_choice(obj_template_t* choicobj, val_value_t* testval);
+
