@@ -169,6 +169,7 @@ extern "C" {
 #define YANGCLI_DISPLAY_MODE  (const xmlChar *)"display-mode"
 #define YANGCLI_ECHO        (const xmlChar *)"echo"
 #define YANGCLI_ECHO_REPLIES (const xmlChar *)"echo-replies"
+#define YANGCLI_ECHO_REQUESTS (const xmlChar *)"echo-requests"
 #define YANGCLI_EDIT_TARGET (const xmlChar *)"edit-target"
 #define YANGCLI_ERROR_OPTION (const xmlChar *)"error-option"
 #define YANGCLI_FILES       (const xmlChar *)"files"
@@ -197,6 +198,7 @@ extern "C" {
 #define YANGCLI_PASSWORD    (const xmlChar *)"password"
 #define YANGCLI_PROTOCOLS   (const xmlChar *)"protocols"
 #define YANGCLI_PRIVATE_KEY (const xmlChar *)"private-key"
+#define YANGCLI_PRIVATE_KEY_PASS (const xmlChar *)"private-key-pass"
 #define YANGCLI_PUBLIC_KEY  (const xmlChar *)"public-key"
 #define YANGCLI_RESTART_OK  (const xmlChar *)"restart-ok"
 #define YANGCLI_RETRY_INTERVAL (const xmlChar *)"retry-interval"
@@ -447,6 +449,7 @@ typedef struct server_cb_t_ {
     ncx_withdefaults_t   withdefaults;
     int32                defindent;
     boolean              echo_replies;
+    boolean              echo_requests;
     boolean              time_rpcs;
     ncx_name_match_t     match_names;
     boolean              alt_names;
@@ -492,10 +495,8 @@ typedef struct server_cb_t_ {
     dlq_hdr_t            notificationQ;   /* Q of mgr_not_msg_t */
 
     /* support fot auto-get-schema feature */
-    dlq_hdr_t            autoload_modcbQ;  /* Q of autoload_modcb_t */
-    dlq_hdr_t            autoload_devcbQ;  /* Q of autoload_devcb_t */
-    autoload_modcb_t    *autoload_curmod;
-    autoload_devcb_t    *autoload_curdev;
+    dlq_hdr_t            autoload_savedevQ; /* Q of ncx_save_deviations_t */
+    boolean              deviations_applied;
 
     /* support for temp directory for downloaded modules */
     ncxmod_temp_progcb_t *temp_progcb;
@@ -683,19 +684,6 @@ extern const xmlChar *
 extern status_t
     replace_connect_valset (const val_value_t *valset);
 
-
-/********************************************************************
-* FUNCTION get_mgrloadQ
-* 
-*  Get the mgrloadQ value pointer
-* 
-* RETURNS:
-*    mgrloadQ variable
-*********************************************************************/
-extern dlq_hdr_t *
-    get_mgrloadQ (void);
-
-
 /********************************************************************
 * FUNCTION get_aliasQ
 * 
@@ -868,6 +856,9 @@ extern void
                                ses_cb_t *scb,
                                status_t (*get_modules_fn)(server_cb_t*,ses_cb_t*),
                                status_t (*get_module_set_fn)(server_cb_t*,ses_cb_t*));
+status_t
+    process_module_deviations (dlq_hdr_t *savedevQ);
+
 extern status_t
     process_cli_input (server_cb_t *server_cb,
                        int argc,
